import React from 'react';

import clsx from 'clsx';

export interface KintonePluginSelectOptionData {
  key: string;
  value: string;
  label: string;
  disabled?: boolean;
}

interface KintonePluginSelectProps {
  className?: string;
  defaultValue?: string;
  onChange?: (e: React.ChangeEvent<HTMLSelectElement>) => void;
  options: KintonePluginSelectOptionData[];
}

const KintonePluginSelect: React.FC<KintonePluginSelectProps> = (props) => {
  const { className, defaultValue, onChange, options } = props;
  if (!options || options.length === 0) {
    return null; // Return null if no options are provided
  }
  return (
    <div className={clsx('kintoneplugin-select-outer', className)}>
      <div className="kintoneplugin-select">
        <select defaultValue={defaultValue} onChange={onChange}>
          {options.map((option) => (
            <option key={option.key} value={option.value} disabled={option.disabled}>
              {option.label}
            </option>
          ))}
        </select>
      </div>
    </div>
  );
};
export default KintonePluginSelect;
